==> openshift-model-5.8.0-sources.jar: io/fabric8/openshift/api/model/ClusterVersionSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterVersionSpecBuilder extends io.fabric8.openshift.api.model.ClusterVersionSpecFluentImpl<io.fabric8.openshift.api.model.ClusterVersionSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterVersionSpec,io.fabric8.openshift.api.model.ClusterVersionSpecBuilder>{
  public ClusterVersionSpecBuilder() {
    this(false);
  }
  public ClusterVersionSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterVersionSpec(), validationEnabled);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterVersionSpec(), validationEnabled);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent,io.fabric8.openshift.api.model.ClusterVersionSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent,io.fabric8.openshift.api.model.ClusterVersionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withChannel(instance.getChannel()); 
    fluent.withClusterID(instance.getClusterID()); 
    fluent.withDesiredUpdate(instance.getDesiredUpdate()); 
    fluent.withOverrides(instance.getOverrides()); 
    fluent.withUpstream(instance.getUpstream()); 
    this.validationEnabled = validationEnabled; 
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpec instance) {
    this(instance,false);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withChannel(instance.getChannel()); 
    this.withClusterID(instance.getClusterID()); 
    this.withDesiredUpdate(instance.getDesiredUpdate()); 
    this.withOverrides(instance.getOverrides()); 
    this.withUpstream(instance.getUpstream()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterVersionSpec build() {
    ClusterVersionSpec buildable = new ClusterVersionSpec(fluent.getChannel(),fluent.getClusterID(),fluent.getDesiredUpdate(),fluent.getOverrides(),fluent.getUpstream());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterVersionSpecBuilder that = (ClusterVersionSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/ClusterVersionSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterVersionSpecBuilder extends io.fabric8.openshift.api.model.ClusterVersionSpecFluentImpl<io.fabric8.openshift.api.model.ClusterVersionSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ClusterVersionSpec,io.fabric8.openshift.api.model.ClusterVersionSpecBuilder>{
  public ClusterVersionSpecBuilder() {
    this(false);
  }
  public ClusterVersionSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterVersionSpec(), validationEnabled);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterVersionSpec(), validationEnabled);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent,io.fabric8.openshift.api.model.ClusterVersionSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent,io.fabric8.openshift.api.model.ClusterVersionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withChannel(instance.getChannel()); 
    fluent.withClusterID(instance.getClusterID()); 
    fluent.withDesiredUpdate(instance.getDesiredUpdate()); 
    fluent.withOverrides(instance.getOverrides()); 
    fluent.withUpstream(instance.getUpstream()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpec instance) {
    this(instance,false);
  }
  public ClusterVersionSpecBuilder(io.fabric8.openshift.api.model.ClusterVersionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withChannel(instance.getChannel()); 
    this.withClusterID(instance.getClusterID()); 
    this.withDesiredUpdate(instance.getDesiredUpdate()); 
    this.withOverrides(instance.getOverrides()); 
    this.withUpstream(instance.getUpstream()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ClusterVersionSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ClusterVersionSpec build() {
    ClusterVersionSpec buildable = new ClusterVersionSpec(fluent.getChannel(),fluent.getClusterID(),fluent.getDesiredUpdate(),fluent.getOverrides(),fluent.getUpstream());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterVersionSpecBuilder that = (ClusterVersionSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
